/* LowCharFilterReader.java
 *
 * created: Tue Oct 12 1999
 *
 * This file is part of Artemis
 * 
 * Copyright (C) 1999  Genome Research Limited
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header:$
 */

package uk.ac.sanger.pathogens;

import java.io.Reader;
import java.io.IOException;

/**
 *  Objects of this class filter out characters with ASCII codes less than 32,
 *  leaving only normal text characters
 *
 *  @author Kim Rutherford
 *  @version $Id:$
 **/

public class LowCharFilterReader extends Reader {
  /**
   *  Create a new LowCharFilterReader object.
   *  @param in_stream the stream to create the object from
   **/
  public LowCharFilterReader (final Reader in_stream) {
    
  }

  /**
   *  Does the same thing as Reader.read (), but discards .
   */
  public int read(char [] cbuf, int off, int len)
       throws IOException {
    return buffered_reader.read (cbuf, off, len);
  }


  /**
   *  Does the same thing as Reader.close ().
   */
  public void close ()
       throws IOException {
    buffered_reader.close ();
  }

  /**
   *  This is the Reader that was created to the constructor.
   */
  private Reader in_reader;
}
